@@ -69,6 +69,10 @@ class Libfuzzer(Command):
         expect_crash_on_failure: bool = False,
         minimized_stack_depth: Optional[int] = None,
         coverage_filter: Optional[str] = None,
+        analyzer_exe: Optional[str] = None,
+        analyzer_options: Optional[List[str]] = None,
+        analyzer_env: Optional[Dict[str, str]] = None,
+        tools: Optional[Container] = None,
     ) -> None:
         target_options = target_options or []
 
@@ -247,6 +251,43 @@ class Libfuzzer(Command):
             minimized_stack_depth=minimized_stack_depth,
         )
 
+        if analyzer_exe is not None:
+            self.logger.info("creating custom analysis")
+
+            if tools is None:
+                self.logger.error(
+                    "tools container cannot be empty when specifying a custom analyzer"
+                )
+                return None
+
+            analysis_containers = [
+                (ContainerType.setup, containers[ContainerType.setup]),
+                (ContainerType.tools, tools),
+                (ContainerType.analysis, containers[ContainerType.analysis]),
+                (ContainerType.crashes, containers[ContainerType.crashes]),
+            ]
+
+            self.onefuzz.tasks.create(
+                job.job_id,
+                TaskType.generic_analysis,
+                target_exe,
+                analysis_containers,
+                duration=duration,
+                pool_name=pool_name,
+                vm_count=vm_count,
+                reboot_after_setup=reboot_after_setup,
+                target_options=target_options,
+                target_env=target_env,
+                analyzer_exe=analyzer_exe,
+                analyzer_options=analyzer_options,
+                analyzer_env=analyzer_env,
+                tags=tags,
+                prereq_tasks=[fuzzer_task.task_id],
+                colocate=colocate_all_tasks or colocate_secondary_tasks,
+                debug=debug,
+                target_timeout=target_timeout,
+            )
+
     def basic(
         self,
         project: str,
@@ -283,6 +324,10 @@ class Libfuzzer(Command):
         expect_crash_on_failure: bool = False,
         minimized_stack_depth: Optional[int] = None,
         coverage_filter: Optional[File] = None,
+        analyzer_exe: Optional[str] = "powershell.exe",
+        analyzer_options: Optional[List[str]] = None,
+        analyzer_env: Optional[Dict[str, str]] = None,
+        tools: Optional[Container] = None,
     ) -> Optional[Job]:
         """
         Basic libfuzzer job
@@ -340,6 +385,9 @@ class Libfuzzer(Command):
             self.onefuzz.containers.get(readonly_inputs)
             helper.containers[ContainerType.readonly_inputs] = readonly_inputs
 
+        if analyzer_exe is not None:
+            helper.define_containers(ContainerType.analysis)
+
         helper.create_containers()
         helper.setup_notifications(notification_config)
 
@@ -380,6 +428,10 @@ class Libfuzzer(Command):
             expect_crash_on_failure=expect_crash_on_failure,
             minimized_stack_depth=minimized_stack_depth,
             coverage_filter=coverage_filter_blob_name,
+            analyzer_exe=analyzer_exe,
+            analyzer_options=analyzer_options,
+            analyzer_env=analyzer_env,
+            tools=tools,
         )
 
         self.logger.info("done creating tasks")
